@@ -1,13 +1,13 @@
 package Crypt::SDTree;
 
-use 5.010000;
 use strict;
 use warnings;
 
 require Exporter;
 
+our $VERSION = '0.03';
+
 our @ISA = qw(Exporter);
-our $VERSION = 0.02;
 
 BOOT_XS: {
   require DynaLoader;
