@@ -1,12 +1,11 @@
 package Crypt::SDTree::Publish;
 
-use 5.010000;
 use strict;
 use warnings;
 
 use Crypt::SDTree qw(:publish);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
 	publish_new(@_);
@@ -22,8 +21,6 @@ Crypt::SDTree::Publish - Create Broadcast Messages
 
 =head1 SYNOPSIS
 
-  use 5.10.1;
-
   use Crypt::SDTree::Publish;
 
   # create a new publisher with all key maerial
