@@ -1,12 +1,11 @@
 package Crypt::SDTree::Subscribe;
 
-use 5.010000;
 use strict;
 use warnings;
 
 use Crypt::SDTree qw(:subscribe);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
 	subscribe_new(@_);
@@ -22,8 +21,6 @@ Crypt::SDTree::Subscribe - Decrypt Broadcast Messages
 
 =head1 SYNOPSIS
 
-  use 5.10.1;
-
   use Crypt::SDTree::Subscribe;
 
   my $client = Crypt::SDTree::Subscribe->new('keyfile');
